@@ -41,15 +41,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("CancelFlow", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CancelFlowResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CancelFlowResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -70,15 +64,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("CancelMultiFlowSignQRCode", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CancelMultiFlowSignQRCodeResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CancelMultiFlowSignQRCodeResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -100,15 +88,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("CreateBatchCancelFlowUrl", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateBatchCancelFlowUrlResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateBatchCancelFlowUrlResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -129,15 +111,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("CreateConvertTaskApi", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateConvertTaskApiResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateConvertTaskApiResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -147,122 +123,9 @@ class EssClient(AbstractClient):
 
     def CreateDocument(self, request):
         """创建签署流程电子文档
-        适用场景：见创建签署流程接口。
-
+        适用场景：见创建签署流程接口。x0b
         注：该接口需要给对应的流程指定一个模板id，并且填充该模板中需要补充的信息。是“发起流程”接口的前置接口。
 
-        【动态表格传参说明】
-        当模板的 ComponentType='DYNAMIC_TABLE'时（渠道版或集成版），FormField.ComponentValue需要传递json格式的字符串参数，用于确定表头&填充动态表格（支持内容的单元格合并）
-        输入示例1：
-
-        ```
-        {
-            "headers":[
-                {
-                    "content":"head1"
-                },
-                {
-                    "content":"head2"
-                },
-                {
-                    "content":"head3"
-                }
-            ],
-            "rowCount":3,
-            "body":{
-                "cells":[
-                    {
-                        "rowStart":1,
-                        "rowEnd":1,
-                        "columnStart":1,
-                        "columnEnd":1,
-                        "content":"123"
-                    },
-                    {
-                        "rowStart":2,
-                        "rowEnd":3,
-                        "columnStart":1,
-                        "columnEnd":2,
-                        "content":"456"
-                    },
-                    {
-                        "rowStart":3,
-                        "rowEnd":3,
-                        "columnStart":3,
-                        "columnEnd":3,
-                        "content":"789"
-                    }
-                ]
-            }
-        }
-
-        ```
-
-        输入示例2（表格表头宽度比例配置）：
-
-        ```
-        {
-            "headers":[
-                {
-                    "content":"head1",
-                    "widthPercent": 30
-                },
-                {
-                    "content":"head2",
-                    "widthPercent": 30
-                },
-                {
-                    "content":"head3",
-                    "widthPercent": 40
-                }
-            ],
-            "rowCount":3,
-            "body":{
-                "cells":[
-                    {
-                        "rowStart":1,
-                        "rowEnd":1,
-                        "columnStart":1,
-                        "columnEnd":1,
-                        "content":"123"
-                    },
-                    {
-                        "rowStart":2,
-                        "rowEnd":3,
-                        "columnStart":1,
-                        "columnEnd":2,
-                        "content":"456"
-                    },
-                    {
-                        "rowStart":3,
-                        "rowEnd":3,
-                        "columnStart":3,
-                        "columnEnd":3,
-                        "content":"789"
-                    }
-                ]
-            }
-        }
-
-        ```
-        表格参数说明
-
-        | 名称                | 类型    | 描述                                              |
-        | ------------------- | ------- | ------------------------------------------------- |
-        | headers             | Array   | 表头：不超过10列，不支持单元格合并，字数不超过100 |
-        | rowCount            | Integer | 表格内容最大行数                                  |
-        | cells.N.rowStart    | Integer | 单元格坐标：行起始index                           |
-        | cells.N.rowEnd      | Integer | 单元格坐标：行结束index                           |
-        | cells.N.columnStart | Integer | 单元格坐标：列起始index                           |
-        | cells.N.columnEnd   | Integer | 单元格坐标：列结束index                           |
-        | cells.N.content     | String  | 单元格内容，字数不超过100                         |
-
-        表格参数headers说明
-        | 名称                | 类型    | 描述                                              |
-        | ------------------- | ------- | ------------------------------------------------- |
-        | widthPercent   | Integer | 表头单元格列占总表头的比例，例如1：30表示 此列占表头的30%，不填写时列宽度平均拆分；例如2：总2列，某一列填写40，剩余列可以为空，按照60计算。；例如3：总3列，某一列填写30，剩余2列可以为空，分别为(100-30)/2=35                    |
-        | content    | String  | 表头单元格内容，字数不超过100                         |
-
         :param request: Request instance for CreateDocument.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateDocumentRequest`
         :rtype: :class:`tencentcloud.ess.v20201111.models.CreateDocumentResponse`
@@ -273,15 +136,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("CreateDocument", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateDocumentResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateDocumentResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -304,15 +161,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("CreateFlow", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateFlowResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateFlowResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -337,15 +188,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("CreateFlowApprovers", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateFlowApproversResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateFlowApproversResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -369,15 +214,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("CreateFlowByFiles", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateFlowByFilesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateFlowByFilesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -386,7 +225,8 @@ class EssClient(AbstractClient):
 
 
     def CreateFlowEvidenceReport(self, request):
-        """创建出证报告，返回报告 ID。
+        """创建出证报告，返回报告 ID。需要配合出证套餐才能调用。
+        出证需要一定时间，建议调用创建出证24小时之后再通过DescribeFlowEvidenceReport进行查询。
 
         :param request: Request instance for CreateFlowEvidenceReport.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateFlowEvidenceReportRequest`
@@ -398,15 +238,34 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("CreateFlowEvidenceReport", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateFlowEvidenceReportResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.CreateFlowEvidenceReportResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateFlowReminds(self, request):
+        """指定需要批量催办的签署流程Id，批量催办合同，最多100个; 接口失败后返回错误信息
+        注意:
+        该接口不可直接调用，需要联系运营开通后方可调用。
+
+        :param request: Request instance for CreateFlowReminds.
+        :type request: :class:`tencentcloud.ess.v20201111.models.CreateFlowRemindsRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.CreateFlowRemindsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateFlowReminds", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateFlowRemindsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -430,15 +289,32 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("CreateFlowSignReview", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateFlowSignReviewResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.CreateFlowSignReviewResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateFlowSignUrl(self, request):
+        """创建签署链接，需要联系运营人员开白后才可使用
+
+        :param request: Request instance for CreateFlowSignUrl.
+        :type request: :class:`tencentcloud.ess.v20201111.models.CreateFlowSignUrlRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.CreateFlowSignUrlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateFlowSignUrl", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateFlowSignUrlResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -459,15 +335,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("CreateIntegrationEmployees", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateIntegrationEmployeesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateIntegrationEmployeesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -490,15 +360,34 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("CreateMultiFlowSignQRCode", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateMultiFlowSignQRCodeResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.CreateMultiFlowSignQRCodeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreatePrepareFlow(self, request):
+        """创建快速发起流程
+        适用场景：用户通过API 合同文件及签署信息，并可通过我们返回的URL在页面完成签署控件等信息的编辑与确认，快速发起合同.
+        注：该接口文件的resourceId 是通过上传文件之后获取的。
+
+        :param request: Request instance for CreatePrepareFlow.
+        :type request: :class:`tencentcloud.ess.v20201111.models.CreatePrepareFlowRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.CreatePrepareFlowResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreatePrepareFlow", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreatePrepareFlowResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -529,15 +418,32 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("CreateSchemeUrl", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateSchemeUrlResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.CreateSchemeUrlResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateSealPolicy(self, request):
+        """对企业员工进行印章授权
+
+        :param request: Request instance for CreateSealPolicy.
+        :type request: :class:`tencentcloud.ess.v20201111.models.CreateSealPolicyRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.CreateSealPolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateSealPolicy", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateSealPolicyResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -558,15 +464,32 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("DeleteIntegrationEmployees", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DeleteIntegrationEmployeesResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.DeleteIntegrationEmployeesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeleteSealPolicies(self, request):
+        """撤销员工持有的印章权限
+
+        :param request: Request instance for DeleteSealPolicies.
+        :type request: :class:`tencentcloud.ess.v20201111.models.DeleteSealPoliciesRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.DeleteSealPoliciesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteSealPolicies", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteSealPoliciesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -588,15 +511,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("DescribeFileUrls", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeFileUrlsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeFileUrlsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -619,15 +536,32 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("DescribeFlowBriefs", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeFlowBriefsResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.DescribeFlowBriefsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeFlowEvidenceReport(self, request):
+        """查询出证报告，返回报告 URL。
+
+        :param request: Request instance for DescribeFlowEvidenceReport.
+        :type request: :class:`tencentcloud.ess.v20201111.models.DescribeFlowEvidenceReportRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.DescribeFlowEvidenceReportResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeFlowEvidenceReport", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeFlowEvidenceReportResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -649,15 +583,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("DescribeFlowInfo", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeFlowInfoResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeFlowInfoResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -666,8 +594,7 @@ class EssClient(AbstractClient):
 
 
     def DescribeFlowTemplates(self, request):
-        """二期接口-查询模板
-        适用场景：当模板较多或模板中的控件较多时，可以通过查询模板接口更方便的获取自己主体下的模板列表，以及每个模板内的控件信息。该接口常用来配合“创建电子文档”接口作为前置的接口使用。
+        """当模板较多或模板中的控件较多时，可以通过查询模板接口更方便的获取模板列表，以及每个模板内的控件信息。该接口常用来配合“创建电子文档”接口作为前置的接口使用。
 
         :param request: Request instance for DescribeFlowTemplates.
         :type request: :class:`tencentcloud.ess.v20201111.models.DescribeFlowTemplatesRequest`
@@ -679,15 +606,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("DescribeFlowTemplates", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeFlowTemplatesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeFlowTemplatesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -708,15 +629,55 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("DescribeIntegrationEmployees", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeIntegrationEmployeesResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.DescribeIntegrationEmployeesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeIntegrationMainOrganizationUser(self, request):
+        """通过子企业影子账号查询主企业员工账号
+
+        :param request: Request instance for DescribeIntegrationMainOrganizationUser.
+        :type request: :class:`tencentcloud.ess.v20201111.models.DescribeIntegrationMainOrganizationUserRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.DescribeIntegrationMainOrganizationUserResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeIntegrationMainOrganizationUser", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeIntegrationMainOrganizationUserResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeOrganizationGroupOrganizations(self, request):
+        """此API接口用户查询加入集团的成员企业
+
+        :param request: Request instance for DescribeOrganizationGroupOrganizations.
+        :type request: :class:`tencentcloud.ess.v20201111.models.DescribeOrganizationGroupOrganizationsRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.DescribeOrganizationGroupOrganizationsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeOrganizationGroupOrganizations", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeOrganizationGroupOrganizationsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -738,15 +699,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("DescribeOrganizationSeals", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeOrganizationSealsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeOrganizationSealsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -767,15 +722,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("DescribeThirdPartyAuthCode", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeThirdPartyAuthCodeResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeThirdPartyAuthCodeResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -796,15 +745,34 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("GetTaskResultApi", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.GetTaskResultApiResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.GetTaskResultApiResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifyApplicationCallbackInfo(self, request):
+        """新增/删除应用callbackinfo
+        callbackinfo包含： 回调地址和签名key
+        操作：新增/删除
+
+        :param request: Request instance for ModifyApplicationCallbackInfo.
+        :type request: :class:`tencentcloud.ess.v20201111.models.ModifyApplicationCallbackInfoRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.ModifyApplicationCallbackInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyApplicationCallbackInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyApplicationCallbackInfoResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -827,15 +795,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("StartFlow", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.StartFlowResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.StartFlowResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -846,7 +808,7 @@ class EssClient(AbstractClient):
     def UploadFiles(self, request):
         """此接口（UploadFiles）用于文件上传。
         适用场景：用于生成pdf资源编号（FileIds）来配合“用PDF创建流程”接口使用，使用场景可详见“用PDF创建流程”接口说明。
-        调用时需要设置Domain 为 file.ess.tencent.cn，设置Version为2020-12-22
+        调用时需要设置Domain/接口请求域名为 file.ess.tencent.cn，并设置参数Version/版本号为2020-12-22
 
         :param request: Request instance for UploadFiles.
         :type request: :class:`tencentcloud.ess.v20201111.models.UploadFilesRequest`
@@ -858,15 +820,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("UploadFiles", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.UploadFilesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.UploadFilesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -887,15 +843,9 @@ class EssClient(AbstractClient):
             headers = request.headers
             body = self.call("VerifyPdf", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.VerifyPdfResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.VerifyPdfResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
